@@ -198,13 +198,14 @@ ResultIterator Query::exec()
     // vHanda: Maybe this should default to allow searches on all search stores?
     Q_ASSERT_X(!types().isEmpty(), "Akonadi::Search::Query::exec", "A query is being initialized without a type");
     if (types().isEmpty()) {
-        return ResultIterator();
+        return {};
     }
 
     SearchStore *storeMatch = nullptr;
     for (const QSharedPointer<SearchStore> &store : std::as_const(*s_searchStores)) {
         bool matches = true;
-        for (const QString &type : types()) {
+        const auto typeList{types()};
+        for (const QString &type : typeList) {
             if (!store->types().contains(type)) {
                 matches = false;
                 break;
@@ -218,11 +219,11 @@ ResultIterator Query::exec()
     }
 
     if (!storeMatch) {
-        return ResultIterator();
+        return {};
     }
 
     int id = storeMatch->exec(*this);
-    return ResultIterator(id, storeMatch);
+    return {id, storeMatch};
 }
 
 QByteArray Query::toJSON() const
@@ -316,9 +317,17 @@ Query Query::fromJSON(const QByteArray &arr)
 
     if (map.contains(QStringLiteral("customOptions"))) {
         QVariant var = map[QStringLiteral("customOptions")];
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
         if (var.type() == QVariant::Map) {
+#else
+        if (var.userType() == QMetaType::QVariantMap) {
+#endif
             query.d->m_customOptions = map[QStringLiteral("customOptions")].toMap();
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
         } else if (var.type() == QVariant::Hash) {
+#else
+        } else if (var.userType() == QMetaType::QVariantHash) {
+#endif
             QVariantHash hash = var.toHash();
 
             QHash<QString, QVariant>::const_iterator it = hash.constBegin();
@@ -351,7 +360,7 @@ QUrl Query::toSearchUrl(const QString &title)
 Query Query::fromSearchUrl(const QUrl &url)
 {
     if (url.scheme() != QLatin1String("akonadisearch")) {
-        return Query();
+        return {};
     }
 
     QUrlQuery urlQuery(url);
