@@ -50,13 +50,25 @@ Term::Term(const QString &property, const QVariant &value, Term::Comparator c)
     d->m_value = value;
 
     if (c == Auto) {
-        if (value.type() == QVariant::String) {
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
+        auto valueType = value.type();
+        if (valueType == QVariant::String) {
             d->m_comp = Contains;
-        } else if (value.type() == QVariant::DateTime) {
+        } else if (valueType == QVariant::String) {
             d->m_comp = Contains;
         } else {
             d->m_comp = Equal;
         }
+#else
+        auto valueType = value.metaType().id();
+        if (valueType == QMetaType::QString) {
+            d->m_comp = Contains;
+        } else if (valueType == QMetaType::QDateTime) {
+            d->m_comp = Contains;
+        } else {
+            d->m_comp = Equal;
+        }
+#endif
     } else {
         d->m_comp = c;
     }
@@ -277,7 +289,11 @@ namespace
 // and see if they can be converted into date/datetime.
 QVariant tryConvert(const QVariant &var)
 {
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
     if (var.canConvert(QVariant::DateTime)) {
+#else
+    if (var.canConvert<QDateTime>()) {
+#endif
         QDateTime dt = var.toDateTime();
         if (!dt.isValid()) {
             return var;
@@ -326,7 +342,11 @@ Term Term::fromVariantMap(const QVariantMap &map)
     term.setProperty(prop);
 
     QVariant value = map.value(prop);
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
     if (value.type() == QVariant::Map) {
+#else
+    if (value.userType() == QMetaType::QVariantMap) {
+#endif
         QVariantMap map = value.toMap();
         if (map.size() != 1) {
             return term;
