@@ -34,10 +34,10 @@ public:
     Q_REQUIRED_RESULT QString plainText() const;
 
 private Q_SLOTS:
-    void slotSearchLineTextChanged(const QString &text);
-    void slotSearch();
-    void slotResult(const QString &result);
-    void slotError(const QString &errorStr);
+    AKONADI_SEARCH_DEBUG_NO_EXPORT void slotSearchLineTextChanged(const QString &text);
+    AKONADI_SEARCH_DEBUG_NO_EXPORT void slotSearch();
+    AKONADI_SEARCH_DEBUG_NO_EXPORT void slotResult(const QString &result);
+    AKONADI_SEARCH_DEBUG_NO_EXPORT void slotError(const QString &errorStr);
 
 private:
     QPlainTextEdit *const mPlainTextEditor;
