@@ -6,8 +6,7 @@
  *
  */
 
-#ifndef AKONADI_SEARCH_PIM_QUERY_H
-#define AKONADI_SEARCH_PIM_QUERY_H
+#pragma once
 
 #include "search_pim_export.h"
 #include <QByteArray>
@@ -34,5 +33,3 @@ public:
 }
 }
 }
-
-#endif // AKONADI_SEARCH_PIM_QUERY_H
